@@ -7,7 +7,7 @@ use Spreadsheet::ParseExcel;
 use Scalar::Util qw(weaken);
 use Coro;
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 sub new {
   my ($class, $file, $opts) = @_;
@@ -99,6 +99,12 @@ sub sheet {
   return $self;
 }
 
+sub workbook {
+  my $self = shift;
+  my $row = $self->{NEXT_CELL};
+  return $row->[0];
+}
+
 sub worksheet {
   my $self = shift;
   my $row = $self->{NEXT_CELL};
