@@ -3,7 +3,7 @@ package Spreadsheet::ParseExcel::Stream::XLSX;
 use strict;
 use warnings;
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 sub new {
   my ($class, $file, $opts) = @_;
@@ -23,6 +23,9 @@ sub new {
   }, $class;
 }
 
+sub workbook { $_[0]{XLS} }
+sub worksheet { $_[0]{CURR_SHEET}{SHEET} }
+
 sub sheet {
   my $self = shift;
   my $sheet = shift @{$self->{SHEETS}} or return;
